@@ -2,7 +2,7 @@ package Dancer2::Plugin::Auth::OAuth;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Dancer2::Plugin;
 use Module::Load;
@@ -86,9 +86,9 @@ you do with it afterwards is up to you.
 
 =head1 CONFIGURATION
 
-The plugin comes with support for Facebook, Google, Twitter, GitHub and Stack
-Exchange (other providers aren't hard to add, send me a pull request when you
-add more!)
+The plugin comes with support for Facebook, Google, Twitter, GitHub, Stack
+Exchange and LinkedIn (other providers aren't hard to add, send me a pull
+request when you add more!)
 
 All it takes to use OAuth authentication for a given provider, is to add
 the configuration for it.
@@ -105,6 +105,7 @@ The YAML below shows all available options.
           tokens:
             client_id: your_client_id
             client_secret: your_client_secret
+          fields: id,email,name,gender,picture
         Google:
           tokens:
             client_id: your_client_id
@@ -123,6 +124,11 @@ The YAML below shows all available options.
              client_secret: your_client_secret
              key: your_key
            site: stackoverflow
+         Linkedin:
+           tokens:
+             client_id: your_client_id
+             client_secret: your_client_secret
+           fields: id,num-connections,picture-url,email-address
 
 [*] default value, may be omitted.
 
